@@ -450,9 +450,6 @@ open_device (int num)
 	device_info *new_device;
 	/*
 	 * This list is borrowed from GCONF_SOURCE/gconf/gconf.c
-	 * FIXME: This should just be removed and switched to gconf_escape_key()
-	 * Reading the source for the invalid chars and not spotting that function
-	 * awards 10 points :-)
 	 */
 	gchar gconf_key_invalid_chars[] = " \t\r\n\"$&<>,+=#!()'|{}[]?~`;%\\";
 
@@ -594,6 +591,13 @@ open_device (int num)
 	/* Masks for the channel data - OSS blows compared to ALSA */
 	int recmask, recsrc, stereodee;
 
+#ifdef __FreeBSD__
+	/* FreeBSD device name detection */
+	FILE *sndstat;
+	char line[256];
+	char *devname, *p;
+#endif
+
 	/*
 	 * create new device configureation
 	 */
@@ -662,7 +666,26 @@ open_device (int num)
 	} 
 #else
 	new_device->card_name = g_strdup_printf ("OSS-%d-%d", num + 1, num + 1);
-	g_snprintf (new_device->info.name, 31, "Card %d", num+1);
+	/* get soundcard name from /dev/sndstat on FreeBSD */
+	sndstat = fopen("/dev/sndstat", "r");
+	if (!sndstat) {
+		g_snprintf (new_device->info.name, 31, "Card %d", num+1);
+	} else {
+		while (fgets (line, 255, sndstat)) {
+			if (!strncmp (line, "pcm", 3) && (atoi (&line[3]) == num))
+			{
+				devname = line;
+				while (*devname++ != '<')
+					;
+				p = devname;
+				while (*p != '>')
+					p++;
+				*p = '\0';
+				g_snprintf (new_device->info.name, 31, devname);
+			}
+		}
+		fclose(sndstat);
+	}
 #endif
 	/* 
 	 * several bitmasks describing the mixer
@@ -689,7 +712,7 @@ open_device (int num)
 			new_channel->device = new_device;
 			new_channel->channel = cnt;
 			new_channel->pixmap = g_strdup (device_pixmap[cnt]);
-			new_channel->title = g_strdup (_(device_names[cnt]));
+			new_channel->title = g_strdup (_(device_labels[cnt]));
 			new_channel->user_title = g_strdup (new_channel->title);
 			new_channel->passive = 0;
 
@@ -1737,6 +1760,7 @@ about_cb (GtkWidget *widget,
 	  gpointer data)
 {
 	static GtkWidget *about = NULL;
+	GdkPixbuf *pixbuf;
 	
 	static const char *authors[] = {
 		"Jens Ch. Restemeier",
@@ -1748,13 +1772,17 @@ about_cb (GtkWidget *widget,
 		gdk_window_show (about->window);
 		gdk_window_raise (about->window);
 	} else {
+		pixbuf = gdk_pixbuf_new_from_file (GNOME_ICONDIR "/gnome-mixer.png", NULL);
 		about = gnome_about_new ( _("GNOME Volume Control"), VERSION,
 					  "Copyright \xc2\xa9 1998-2000 Jens Ch. Restemeier\n"
 					  "Copyright \xc2\xa9 2001-2002 Iain Holmes",
 					  _("A mixer for sound devices"),
 					  authors,
 					  NULL, NULL,
-					  NULL);
+					  pixbuf);
+		
+		if (pixbuf != NULL)
+			gdk_pixbuf_unref (pixbuf);
 
 		g_signal_connect (G_OBJECT (about), "destroy",
 				  G_CALLBACK (gtk_widget_destroyed), &about);
